Struct DiffTensor

pub struct DiffTensor<T, B = Cpu, const DEVICE_ID: usize = 0, A = HptAllocator<B>>
where B: BackendTy + Buffer, A: Allocator,
{ /* private fields */ }
DiffTensor is a tensor that has a gradient.

Implementations

Source

impl<T, const DEVICE: usize, A> DiffTensor<T, Cpu, DEVICE, A>
where A: Allocator + Send + Sync + 'static, A::Output: AllocatorOutputRetrive,

pub fn log_softmax( &self, axis: i64, ) -> Result<DiffTensor<<T as FloatOutUnary>::Output, Cpu, DEVICE, A>, TensorError>

Applies the logsoftmax function along a specified axis.

The logsoftmax function normalizes the elements along the specified axis such that they sum to 1. It is commonly used in machine learning models, particularly for multi-class classification tasks. The logsoftmax function transforms each element x_i in the input tensor into a probability by computing:

logsoftmax(x_i) = log(exp(x_i) / sum(exp(x_j))) for all j along the specified axis
Arguments
  • axis - The axis along which to apply the softmax function. The elements along this axis will be transformed into probabilities that sum to 1.
Returns

This function returns a Result containing a tensor with the softmax values computed along the specified axis.

Source

impl<T, const DEVICE: usize, A> DiffTensor<T, Cpu, DEVICE, A>
where A: Allocator + Send + Sync + 'static, A::Output: AllocatorOutputRetrive,

pub fn softmax( &self, axis: i64, ) -> Result<DiffTensor<<T as FloatOutUnary>::Output, Cpu, DEVICE, A>, TensorError>

Applies the softmax function along a specified axis.

The softmax function normalizes the elements along the specified axis such that they sum to 1. It is commonly used in machine learning models, particularly for multi-class classification tasks. The softmax function transforms each element x_i in the input tensor into a probability by computing:

softmax(x_i) = exp(x_i) / sum(exp(x_j)) for all j along the specified axis
Arguments
  • axis - The axis along which to apply the softmax function. The elements along this axis will be transformed into probabilities that sum to 1.
Returns

This function returns a Result containing a tensor with the softmax values computed along the specified axis.

Source

impl<T: Clone, const DEVICE: usize> DiffTensor<T, Cpu, DEVICE>

pub fn backward( &mut self, grad: Tensor<T, Cpu, DEVICE>, ) -> Result<(), TensorError>

Backward the gradient of the tensor

pub fn grad(&self) -> Option<Tensor<T, Cpu, DEVICE>>

Get the gradient of the tensor

Source

impl<T, const DEVICE: usize, Al> DiffTensor<T, Cpu, DEVICE, Al>
where Al: Allocator,

pub fn new<A>(data: A) -> Self
where A: Into<Tensor<T, Cpu, DEVICE, Al>>,

Creates a new differentiable tensor from the provided data.