pub struct DiffTensor<T, B = Cpu, const DEVICE_ID: usize = 0, A = HptAllocator<B>>{ /* private fields */ }Expand description
DiffTensor is a tensor that has a gradient.
Implementations
Sourceimpl<T, const DEVICE: usize, A> DiffTensor<T, Cpu, DEVICE, A>
impl<T, const DEVICE: usize, A> DiffTensor<T, Cpu, DEVICE, A>
Sourcepub fn log_softmax(
&self,
axis: i64,
) -> Result<DiffTensor<<T as FloatOutUnary>::Output, Cpu, DEVICE, A>, TensorError>where
T: CommonBounds + Cast<<T as FloatOutUnary>::Output> + FloatOutUnary,
<T as FloatOutUnary>::Output: CommonBounds + NormalOut<T, Output = <T as FloatOutUnary>::Output> + FloatOutUnary<Output = <T as FloatOutUnary>::Output> + Cast<T>,
T::Vec: FloatOutUnary<Output = <<T as FloatOutUnary>::Output as TypeCommon>::Vec> + IntoVec<<<T as FloatOutUnary>::Output as TypeCommon>::Vec>,
<<T as FloatOutUnary>::Output as TypeCommon>::Vec: FloatOutBinary<Output = <<T as FloatOutUnary>::Output as TypeCommon>::Vec> + FloatOutUnary<Output = <<T as FloatOutUnary>::Output as TypeCommon>::Vec>,
pub fn log_softmax(
&self,
axis: i64,
) -> Result<DiffTensor<<T as FloatOutUnary>::Output, Cpu, DEVICE, A>, TensorError>where
T: CommonBounds + Cast<<T as FloatOutUnary>::Output> + FloatOutUnary,
<T as FloatOutUnary>::Output: CommonBounds + NormalOut<T, Output = <T as FloatOutUnary>::Output> + FloatOutUnary<Output = <T as FloatOutUnary>::Output> + Cast<T>,
T::Vec: FloatOutUnary<Output = <<T as FloatOutUnary>::Output as TypeCommon>::Vec> + IntoVec<<<T as FloatOutUnary>::Output as TypeCommon>::Vec>,
<<T as FloatOutUnary>::Output as TypeCommon>::Vec: FloatOutBinary<Output = <<T as FloatOutUnary>::Output as TypeCommon>::Vec> + FloatOutUnary<Output = <<T as FloatOutUnary>::Output as TypeCommon>::Vec>,
Applies the logsoftmax function along a specified axis.
The logsoftmax function normalizes the elements along the specified axis such that they sum to 1.
It is commonly used in machine learning models, particularly for multi-class classification tasks.
The logsoftmax function transforms each element x_i in the input tensor into a probability by computing:
logsoftmax(x_i) = log(exp(x_i) / sum(exp(x_j))) for all j along the specified axisArguments
axis- The axis along which to apply the softmax function. The elements along this axis will be transformed into probabilities that sum to 1.
Returns
This function returns a Result containing a tensor with the softmax values computed along
the specified axis.
Sourceimpl<T, const DEVICE: usize, A> DiffTensor<T, Cpu, DEVICE, A>
impl<T, const DEVICE: usize, A> DiffTensor<T, Cpu, DEVICE, A>
Sourcepub fn softmax(
&self,
axis: i64,
) -> Result<DiffTensor<<T as FloatOutUnary>::Output, Cpu, DEVICE, A>, TensorError>where
T: CommonBounds + Cast<<T as FloatOutUnary>::Output> + FloatOutUnary,
<T as FloatOutUnary>::Output: CommonBounds + NormalOut<T, Output = <T as FloatOutUnary>::Output> + FloatOutUnary<Output = <T as FloatOutUnary>::Output> + Cast<T>,
T::Vec: FloatOutUnary<Output = <<T as FloatOutUnary>::Output as TypeCommon>::Vec>,
<<T as FloatOutUnary>::Output as TypeCommon>::Vec: FloatOutBinary<Output = <<T as FloatOutUnary>::Output as TypeCommon>::Vec>,
pub fn softmax(
&self,
axis: i64,
) -> Result<DiffTensor<<T as FloatOutUnary>::Output, Cpu, DEVICE, A>, TensorError>where
T: CommonBounds + Cast<<T as FloatOutUnary>::Output> + FloatOutUnary,
<T as FloatOutUnary>::Output: CommonBounds + NormalOut<T, Output = <T as FloatOutUnary>::Output> + FloatOutUnary<Output = <T as FloatOutUnary>::Output> + Cast<T>,
T::Vec: FloatOutUnary<Output = <<T as FloatOutUnary>::Output as TypeCommon>::Vec>,
<<T as FloatOutUnary>::Output as TypeCommon>::Vec: FloatOutBinary<Output = <<T as FloatOutUnary>::Output as TypeCommon>::Vec>,
Applies the softmax function along a specified axis.
The softmax function normalizes the elements along the specified axis such that they sum to 1.
It is commonly used in machine learning models, particularly for multi-class classification tasks.
The softmax function transforms each element x_i in the input tensor into a probability by computing:
softmax(x_i) = exp(x_i) / sum(exp(x_j)) for all j along the specified axisArguments
axis- The axis along which to apply the softmax function. The elements along this axis will be transformed into probabilities that sum to 1.
Returns
This function returns a Result containing a tensor with the softmax values computed along
the specified axis.